---
name: Improve documentation
about: Help us improve our documentation
title: "[DOC] - title of the issue"
labels: documentation
assignees: ''

---

# What were you looking for
Please try to describe in a concise way which kind of information you were looking for and where were you looking.

# Is the information available in the doc but not where you would expect?
let us know if you ended up finding the information you were looking for in another (unexpected) section of the doc.

# Is information completely lacking or partial?
please specify if you are asking for better explanation/clarification of the text or if the information is completely lacking.

# Where would you insert the missing information?
describe here where you would put the information.

# Additional context
you can use this space to give any other additional information that you think would be useful to solve the issue.
